>From 73222c324db9d019f3daa1097e8c8aeb64507375 Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Sat, 13 Aug 2011 02:54:44 +0300
Subject: [carFl mem 03/65] Implement read_chunk_from_file

Reads chunk at start position. Drop long type usage here, as int
is sufficient. This is tricky, but I hope it will provide a better
interface for implementing serial communication.

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 flashrom.c |   13 +++++++------
 1 files changed, 7 insertions(+), 6 deletions(-)

diff --git a/flashrom.c b/flashrom.c
index 01276ce..5f87e2f 100644
--- a/flashrom.c
+++ b/flashrom.c
@@ -1263,10 +1263,10 @@ int read_buf_from_file(unsigned char *buf, unsigned long size,
 	return 0;
 }
 
-int read_chunk_from_file(unsigned char *buf, unsigned long size,
-		       const char *filename)
+int read_chunk_from_file(unsigned char *buf, unsigned int start,
+			unsigned int size, const char *filename)
 {
-	unsigned long numbytes;
+	unsigned int numbytes;
 	FILE *image;
 	struct stat image_stat;
 
@@ -1279,19 +1279,20 @@ int read_chunk_from_file(unsigned char *buf, unsigned long size,
 		fclose(image);
 		return 1;
 	}
-	if (image_stat.st_size != size) {
+	if (image_stat.st_size < 4096) { //should be flash size
 		msg_gerr("Error: Image size doesn't match\n");
 		fclose(image);
 		return 1;
 	}
+	fseek(image, start, SEEK_SET);
 	numbytes = fread(buf, 1, size, image);
 	if (fclose(image)) {
 		perror(filename);
 		return 1;
 	}
 	if (numbytes != size) {
-		msg_gerr("Error: Failed to read complete file. Got %ld bytes, "
-			 "wanted %ld!\n", numbytes, size);
+		msg_gerr("Error: Failed to read file. Got %d bytes, "
+			 "wanted %d!\n", numbytes, size);
 		return 1;
 	}
 	return 0;
-- 
1.7.6

